@@ -8,7 +8,7 @@ no warnings "experimental::signatures";
 no warnings "experimental::smartmatch";
 use Hash::Merge;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 require Exporter;
 
@@ -201,8 +201,20 @@ Rajkumar Reddy
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2022 by Rajkumar Reddy
+Copyright (C) 2022 by Rajkumar Reddy. All rights reserved.
+
+This program is free software: you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation, either version 3 of the License, or
+(at your option) any later version.
+
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
-Opensourced
 
 =cut
